@@ -16,12 +16,13 @@ from __future__ import absolute_import
 
 import clusterondemand.brightsetup
 from clusterondemand.bcm_version import BcmVersion
-from clusterondemand.configuration import NO_WLM
+from clusterondemand.configuration import CFG_NO_ADMIN_EMAIL, NO_WLM
 from clusterondemandconfig import config
 
 
 def generate_bright_setup(hostname, head_node_sg_id, node_sg_id, existing_subnet_ids):
     license_dict = clusterondemand.brightsetup.get_license_dict(hostname)
+    admin_email = config["admin_email"] if config["admin_email"] != CFG_NO_ADMIN_EMAIL else None
     brightsetup = clusterondemand.brightsetup.generate_bright_setup(
         cloud_type="aws",
         wlm=config["wlm"] if config["wlm"] != NO_WLM else "",
@@ -29,6 +30,7 @@ def generate_bright_setup(hostname, head_node_sg_id, node_sg_id, existing_subnet
         password=config["cluster_password"],
         node_count=config["nodes"],
         timezone=config["timezone"],
+        admin_email=admin_email,
         license_dict=license_dict,
         node_kernel_modules=["nvme", "ena"],
         node_disk_setup_path="/root/cm/node-disk-setup.xml"
