@@ -15,6 +15,7 @@
 from __future__ import absolute_import
 
 import collections
+import hashlib
 import logging
 from enum import Enum, auto
 from functools import lru_cache
@@ -188,8 +189,20 @@ class Cluster(object):
 
         for instance_id, private_ip_addresses in eip_and_associations.items():
             for private_ip_address in private_ip_addresses:
+                if not self.is_ha:
+                    ip_type = self.IpType.A
+                else:
+                    if instance_id == self.primary_head_node.id and private_ip_address["Primary"]:
+                        ip_type = self.IpType.A
+                    elif instance_id == self.active_head_node.id and not private_ip_address["Primary"]:
+                        ip_type = self.IpType.HA
+                    elif instance_id == self.secondary_head_node.id and private_ip_address["Primary"]:
+                        ip_type = self.IpType.B
+
                 if private_ip_address.get("Association"):  # A public EIP is bound to the private_ip_address
-                    return  # If Elastic IP already assigned, do nothing
+                    allocation_ip = private_ip_address.get("Association")["PublicIp"]
+                    cluster_ips.append((allocation_ip, ip_type.name))
+                    continue  # If Elastic IP already assigned, don't allocate a new one
 
                 # https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.allocate_address
                 allocation = self.ec2c.allocate_address(Domain="vpc")
@@ -209,15 +222,6 @@ class Cluster(object):
                         raise CODException("Error assigning IP", caused_by=release_error)
                     raise CODException("Error assigning IP", caused_by=allocate_error)
 
-                if not self.is_ha:
-                    ip_type = self.IpType.A
-                else:
-                    if instance_id == self.primary_head_node.id and private_ip_address["Primary"]:
-                        ip_type = self.IpType.A
-                    elif instance_id == self.active_head_node.id and not private_ip_address["Primary"]:
-                        ip_type = self.IpType.HA
-                    elif instance_id == self.secondary_head_node.id and private_ip_address["Primary"]:
-                        ip_type = self.IpType.B
                 self.tag_eip(ip_type=ip_type, epialloc_id=allocation_id)
                 cluster_ips.append((allocation_ip, ip_type.name))
         if self.is_ha:
@@ -246,9 +250,19 @@ class Cluster(object):
                               f"no Elastic IP associated, nothing to release")
 
     def get_efs_id(self):
-        efs_creation_token = f"bcm-ha-efs-{self.name}"  # Generated by cm-cloud-ha (see cluster-tools repo)
+        # The creation token is originally generated by cm-cloud-ha (see cluster-tools repo)
+        # To be backward compatible, we check using both the old format and the new format
+        old_efs_creation_token = f"bcm-ha-efs-{self.name}"
+        efs_creation_token = hashlib.sha256(f"bcm-ha-efs-{self.name}".encode("utf-8")).hexdigest()
+
         response = efs.describe_fs(self.efs_client, token=efs_creation_token)
-        return response["FileSystemId"] if response else None
+        if response:
+            return response["FileSystemId"]
+        elif len(old_efs_creation_token) <= 64:
+            response = efs.describe_fs(self.efs_client, token=old_efs_creation_token)
+            return response["FileSystemId"] if response else None
+        else:
+            return None
 
     def try_delete_efs(self):
         fs_id = self.get_efs_id()
@@ -349,6 +363,9 @@ class Cluster(object):
     @classmethod
     def stop(cls, clusters, release_eip):
         if release_eip:
+            log.info("The elastic IP(s) will be released as part of the stop process in order to reduce costs. "
+                     "The next time the cluster is started, it will have a different IP. "
+                     "Use --no-release-eip to retain the same IP(s) in between stop/start operations.")
             for cluster in clusters:
                 cluster.release_eips()
 
