@@ -38,6 +38,7 @@ from clusterondemandaws.vpc import get_aws_tag
 from clusterondemandconfig import ConfigNamespace, config
 from clusterondemandconfig.configuration_validation import (
     if_disabled_require_other_paramaters_to_be_disabled,
+    if_not_set_requires_other_parameters_to_be_set,
     requires_other_parameters_to_be_set
 )
 
@@ -409,20 +410,6 @@ config_ns.add_parameter(
          "Related parameter: --head-node-sg-id",
     validation=requires_other_parameters_to_be_set(["node_sg_id"])
 )
-config_ns.add_enumeration_parameter(
-    "prebs",
-    default=[],
-    help_varname="COMMAND",
-    help=("Command(s) executed by cloud-init before "
-          "cm-bright-setup (before CMDaemon starts). Useful for package update."
-          " Multiple arguments are allowed")
-)
-config_ns.add_enumeration_parameter(
-    "postbs",
-    default=[],
-    help_varname="COMMAND",
-    help="Command(s) executed by cloud-init post cm-bright-setup (Once CMDaemon starts)"
-)
 config_ns.add_parameter(
     "head_node_pg_name",
     advanced=True,
@@ -433,7 +420,8 @@ config_ns.add_parameter(
     help_varname="PROFILE",
     help="Instance profile to assign to the head node. Can be specified as short name or full ARN. The cluster will be "
          "configured to obtain credentials from the meta-data endpoint. The values of the --aws-access-key-id and "
-         "--aws-secret-key settings will not be used by the head node CMDaemon."
+         "--aws-secret-key settings will not be used by the head node CMDaemon.",
+    validation=if_not_set_requires_other_parameters_to_be_set(["aws_access_key_id", "aws_secret_key"]),
 )
 
 
