@@ -23,11 +23,15 @@ from clusterondemandconfig import config
 log = logging.getLogger("cluster-on-demand")
 
 
-def establish_connection_to_ec2():
+def establish_connection_to_aws():
     log.debug("Establish session with AWS region '%s'" % config["aws_region"])
     session = boto3.session.Session(config["aws_access_key_id"],
                                     config["aws_secret_key"],
                                     region_name=config["aws_region"])
+    return session
+
+
+def create_ec2_resource_client(session):
     return session.resource(
         "ec2", api_version="2016-11-15"
     ), session.client(
