@@ -20,7 +20,7 @@ from clusterondemand.images.find import CODImage, ImageSource
 from clusterondemand.images.find import findimages_ns as common_findimages_ns
 from clusterondemandconfig import ConfigNamespace, config
 
-from .ec2connection import establish_connection_to_ec2
+from .ec2connection import create_ec2_resource_client, establish_connection_to_aws
 
 log = logging.getLogger("cluster-on-demand")
 
@@ -55,27 +55,36 @@ class AWSImageSource(ImageSource):
         )
 
     def _iter_from_source(self):
-        ec2, ec2c = establish_connection_to_ec2()
+        allow_custom_images = False
+        image_owners = []
+        image_ids = []
+        filters = []
 
-        image_owner = config["image_owner"]
+        if self.uuids:
+            # Find images by AMI ids. They might be non-Bright
+            image_ids = self.uuids[:]
+            allow_custom_images = True
+        else:
+            image_owners = [config["image_owner"]]
 
-        filters = [
-            {"Name": "name", "Values": ["brightheadnode-*"]},
-        ]
+            filters = [
+                {"Name": "name", "Values": ["brightheadnode-*"]},
+            ]
 
-        if config["image_visibility"] == "public":
-            filters += [{"Name": "is-public", "Values": ["true"]}]
-        elif config["image_visibility"] == "private":
-            filters += [{"Name": "is-public", "Values": ["false"]}]
-        elif config["image_visibility"] == "any":
-            # not specifying a filter will result in both public and private be fetched
-            pass
+            if config["image_visibility"] == "public":
+                filters += [{"Name": "is-public", "Values": ["true"]}]
+            elif config["image_visibility"] == "private":
+                filters += [{"Name": "is-public", "Values": ["false"]}]
+            elif config["image_visibility"] == "any":
+                # not specifying a filter will result in both public and private be fetched
+                pass
 
-        images = list(ec2.images.filter(Owners=[image_owner], Filters=filters))
+        ec2, _ = create_ec2_resource_client(establish_connection_to_aws())
+        images = list(ec2.images.filter(Owners=image_owners, Filters=filters, ImageIds=image_ids))
 
         for image in images:
             try:
-                cod_image = make_cod_image_from_aws(image)
+                cod_image = make_cod_image_from_aws(image, allow_custom_images=allow_custom_images)
             except CannotParseImageName as e:
                 # This is parsing names of public images, someone could even upload some bogus name
                 # to break our code. So we just ignore if we can't parse it
@@ -85,22 +94,33 @@ class AWSImageSource(ImageSource):
                 yield cod_image
 
 
-def make_cod_image_from_aws(amazon_image):
-    match = re.match(IMAGE_NAME_REGEX_AWS, amazon_image.name)
-    if not match:
-        raise CannotParseImageName(f"Cannot parse image name {amazon_image.name}")
+def make_cod_image_from_aws(amazon_image, allow_custom_images=False):
+    """
+    Convert boto3's image object to COD image object
 
-    version, distribution, revision = match.groups()
+    :param amazon_image: boto3.resource image object
+    :param allow_custom_images: allow non-Bright images
+    :return: CODImage object for specified image
+    """
+    additional_params = {}
+    match = re.match(IMAGE_NAME_REGEX_AWS, amazon_image.name)
+    if match:
+        version, distribution, revision = match.groups()
+        additional_params = {
+            "version": version,
+            "distro": distribution,
+            "revision": int(revision),
+            "id": f"{distribution}-{version}",
+        }
+    elif not allow_custom_images:
+        raise CannotParseImageName(f"Cannot parse image name {amazon_image.name}")
 
     return CODImage(
         name=amazon_image.name,
-        id=f"{distribution}-{version}",
         uuid=amazon_image.id,
-        revision=int(revision),
-        distro=distribution,
-        version=version,
         created_at=datetime.fromisoformat(amazon_image.creation_date.replace("Z", "+00:00")),
         image_visibility="public" if amazon_image.public else "private",
         type="headnode",
         cloud_type="aws",
+        **additional_params,
     )
