@@ -25,11 +25,11 @@ import six.moves.urllib.request
 
 import clusterondemand.configuration
 from clusterondemand.codoutput.sortingutils import SortableData
-from clusterondemand.exceptions import CODException, UserReportableException
+from clusterondemand.exceptions import CODException
 from clusterondemandconfig import ConfigNamespace, config
 
-from .configuration import awscommon_ns, awsinstancetype_ns
-from .instancetype import NoTypesXMLError, get_available_instance_types, list_regions
+from .configuration import awscommon_ns
+from .instancetype import get_available_instance_types, list_regions
 
 columns = [
     ("region", "Region"),
@@ -39,12 +39,9 @@ log = logging.getLogger("cluster-on-demand")
 
 
 HR = "---------------------------------------------------------------------"
-TYPES_URL = "http://support.brightcomputing.com/cloudproviders/amazon/types.xml"
-
 
 config_ns = ConfigNamespace("aws.instancetype.list", "list output parameters")
 config_ns.import_namespace(awscommon_ns)
-config_ns.import_namespace(awsinstancetype_ns)
 config_ns.import_namespace(clusterondemand.configuration.clusterlist_ns)
 config_ns.add_enumeration_parameter(
     "sort",
@@ -81,10 +78,7 @@ class InstanceTypesList(object):
     @classmethod
     def map_regions_to_instance_types(cls, chosen_region=None):
         regions = [chosen_region] if chosen_region else list_regions()
-        instance_types = get_available_instance_types()
-        mapping = {region: types for region, types in six.iteritems(instance_types)
-                   if region in regions}
-        return mapping
+        return {region: get_available_instance_types(region) for region in regions}
 
     def output_json_file(self):
         """Print out all mappings in JSON format."""
@@ -127,13 +121,7 @@ class InstanceTypesList(object):
                 )
             )
 
-        try:
-            self.mapping = self.map_regions_to_instance_types(region)
-        except NoTypesXMLError as e:
-            raise UserReportableException(
-                f"Failed to read instance types file from '{e.url}'. You can use --types-url to set a different URL or "
-                f"use --fetch-from-aws to use the (slower) AWS pricing API directly."
-            )
+        self.mapping = self.map_regions_to_instance_types(region)
 
         if config["output_format"] == "json":
             self.output_json_file()
