@@ -37,7 +37,7 @@ def list_availability_zones(region, aws_key_id, aws_secret):
 
 
 class AWSParamValidator(object):
-    valid_instance_types = None  # cache to avoid repeated fetches
+    valid_instance_types = dict()  # cache to avoid repeated fetches
 
     @staticmethod
     def validate_availability_zone(availability_zone, region, aws_key_id, aws_secret):
@@ -46,13 +46,13 @@ class AWSParamValidator(object):
         )
 
     @staticmethod
-    def validate_region(region, aws_key_id, aws_secret):
+    def validate_region(region):
         return region in list_regions()
 
     @classmethod
     def validate_instance_type(cls, region, instance_type):
-        if cls.valid_instance_types is None:
-            cls.valid_instance_types = get_available_instance_types()
+        if region not in cls.valid_instance_types:
+            cls.valid_instance_types[region] = get_available_instance_types(region)
 
         return instance_type in cls.valid_instance_types[region]
 
