@@ -40,8 +40,10 @@ class AwsSummaryGenerator(SummaryGenerator):
         self._vpc_id = vpc_id
         self._vpc_cidr = vpc_cidr_block
         self._subnet_texts = subnet_texts if subnet_texts else []
+        self._use_instance_profile = config["headnode_instance_profile"]
 
     def _add_rows(self, table):
+        self._add_credentials_message(table)
         if self._config["existing_vpc_id"]:
             self._add_existing_vpc(table)
 
@@ -58,6 +60,12 @@ class AwsSummaryGenerator(SummaryGenerator):
         for cluster in self._requested_clusters:
             table.add_row(["Cluster:", cluster.name])
 
+    def _add_credentials_message(self, table):
+        if self._use_instance_profile:
+            table.add_row(["Cloud authentication:", "Head node will use instance profile for cloud authentication"])
+        else:
+            table.add_row(["Cloud authentication:", "Head node will inherit COD credentials for cloud authentication"])
+
     def _add_existing_vpc(self, table):
         table.add_row(["Existing VPC:", f"{self._vpc_name} ({self._vpc_id}, {self._vpc_cidr})"])
         if not self._config["head_node_assign_public_ip"]:
@@ -72,4 +80,4 @@ class AwsSummaryGenerator(SummaryGenerator):
         if len(self._requested_clusters) == 1:
             head_ip = self._config["head_node_internal_ip"] if self._config["head_node_internal_ip"] \
                 else "<auto> (set with --head-node-internal-ip)"
-            table.add_row(["Head node IP: ", head_ip])
+            table.add_row(["Head node IP:", head_ip])
