@@ -15,6 +15,7 @@
 from __future__ import absolute_import
 
 import logging
+import re
 import shlex
 import time
 import yaml
@@ -371,6 +372,16 @@ def _create_head_node(vpc, hostname, public_subnet, head_node_image, head_node_s
         {"ResourceType": "volume", "Tags": headnode_ebs_tags},
     ]
 
+    if config["headnode_instance_profile"]:
+        if re.match(r"arn:aws:iam::(\d+):instance-profile/(\w+)", config["headnode_instance_profile"]):
+            field = "Arn"
+        else:
+            field = "Name"
+
+        kwargs["IamInstanceProfile"] = {
+            field: config["headnode_instance_profile"]
+        }
+
     instances = public_subnet.create_instances(**kwargs)
     head_node_instance = instances[0]
     log.info(f"Created VM {head_node_instance.id}")
